from src.api.trackable_object import TrackableObject
from src.api.api_utils import parse_str_to_date
import datetime

class Astronaut(TrackableObject):

    def __init__(self,astronaut_json):
        self.name = astronaut_json.get("name")
        self.status = astronaut_json.get("status").get("name")
        self.type = astronaut_json.get("type").get("name")
        self.date_of_birth = datetime.date.fromisoformat(astronaut_json.get("date_of_birth"))
        if astronaut_json.get("date_of_death") != None:
            self.date_of_death = datetime.date.fromisoformat(astronaut_json.get("date_of_death"))
        self.nationality = astronaut_json.get("nationality")
        self.bio = astronaut_json.get("bio")
        self.twitter = astronaut_json.get("twitter")
        self.instagram = astronaut_json.get("instagram")
        self.wiki = astronaut_json.get("wiki")
        if astronaut_json.get("agency") != None:
            self.agency = astronaut_json.get("agency")
        else:
            self.agency = "N/A"
        self.profile_image = astronaut_json.get("profile_image")

    def __repr__(self):
        return """
        \nNAME: {}
        \nSTATUS: {}
        \nAGENCY: {} ({}) | {}
        \nBIO: 
        \nDate Of Birth: {}
        \n{}
        \nSOCIAL:
        \n Wiki: {}
        \n Twitter: {}
        \n Instagram: {}
        """.format(
            self.name,
            self.status,
            self.agency.get("name"),self.agency.get("abbrev"),self.agency.get("type"),
            self.date_of_birth,
            self.bio,
            self.wiki,self.twitter,self.instagram)

    def track_global_coordinates(self):
        return None


from src.api.trackable_object import TrackableObject
from src.api.api_utils import parse_str_to_date
import datetime

class SpaceStation(TrackableObject):

    def __init__(self,station_json):
        self.name = station_json.get("name")
        self.status = station_json.get("status").get("name")
        self.orbit = station_json.get("orbit")
        self.type = station_json.get("type").get("name")
        self.description = station_json.get("description")
        self.founded_date = station_json.get("founded")
        self.global_coordinates = {"latitude":"","longitude":""}
        self.owners = ["{}({})".format(x.get("name"),x.get("abbrev")) for x in station_json.get("owners")]

    def __repr__(self):

        return """
        \nNAME: {}
        \nSTATUS: {}\tTYPE: {} 
        \nORBIT: {}
        \n{}
        \nFOUNDED: {}
        \nOWNERS: \n\t{}
        """.format(
            self.name,
            self.status, self.type,
            self.orbit,
            self.description,
            self.founded_date,
            "\n\t".join(self.owners)
            )

    def track_global_coordinates(self):
        return float(self.global_coordinates["latitude"]),float(self.global_coordinates["longitude"])



import requests
import src.const as const
from .launch import Launch
from .astronaut import Astronaut
from .space_station import SpaceStation
from .event import Event
from .body import Body
from pprint import pprint
import logging
from collections import OrderedDict
"""
Provides functions that call / parse / format data from the multiple apis
"""

class Api_Manager():
    """
    Class that manages variables and provides methods to fetch the APIs 
    """

    def __init__(self,app):
        self.app = app
        self.pages = {
            const.API_TYPES.LAUNCHES: Api_Page(),
            const.API_TYPES.ASTRONAUTS: Api_Page(),
            const.API_TYPES.SPACE_STATIONS: Api_Page(),
            const.API_TYPES.EVENTS: Api_Page(),
            const.API_TYPES.SOLAR_SYSTEM_BODIES: Api_Page(offset_delta=1)
        }
        
        # Dict of Functions that get data using the api
        self.getters_dict = {
            const.API_TYPES.LAUNCHES:self.get_upcoming_launches,
            const.API_TYPES.ASTRONAUTS:self.get_astronauts,
            const.API_TYPES.SPACE_STATIONS:self.get_space_stations,
            const.API_TYPES.EVENTS:self.get_events,
            const.API_TYPES.SOLAR_SYSTEM_BODIES: self.get_solar_system_bodies
        }

    def get_solar_system_bodies(self,next_page=None):
        url = "https://api.le-systeme-solaire.net/rest.php/bodies?page={}"
        self.update_api_page(self.pages[const.API_TYPES.SOLAR_SYSTEM_BODIES],next_page,url,"englishName",Body,list_key="bodies")

    def get_events(self,next_page=None):
        url = "https://spacelaunchnow.me/api/3.3.0/event/upcoming/?format=json&offset={}"
        self.update_api_page(self.pages[const.API_TYPES.EVENTS],next_page,url,"name",Event)

    def get_astronauts(self,next_page=None):
        """
        Gets upcoming launches, updates paging
        Args:
            next: Boolean, gets the next page of objects if True. Gets the previous if False. Gets of the same page if None
        Returns:
            The resullting Api Page
        """
        url = "https://spacelaunchnow.me/api/3.3.0/astronaut/?&offset={}&status=1"
        self.update_api_page(self.pages[const.API_TYPES.ASTRONAUTS],next_page,url,"name",Astronaut)

    def get_upcoming_launches(self,next_page=None):
        """
        Gets upcoming launches, updates paging
        Args:
            next: Boolean, gets the next page of objects if True. Gets the previous if False
        Returns:
            The resullting Api Page
        """
        url = "https://spacelaunchnow.me/api/3.3.0/launch/upcoming/?format=json&offset={}"
        self.update_api_page(self.pages[const.API_TYPES.LAUNCHES],next_page,url,"name",Launch)

    def get_space_stations(self,next_page=None):
        page = self.pages[const.API_TYPES.SPACE_STATIONS] # ref
        url = "https://spacelaunchnow.me/api/3.3.0/spacestation/?format=json&status=1&offset={}"
        self.update_api_page(page,next_page,url,"name",SpaceStation)
        
        #Get current ISS location
        if "International Space Station" in page.results_dict.keys():            
            json_results = request_json("http://api.open-notify.org/iss-now.json")
            iss_position = json_results["iss_position"]
            page.results_dict["International Space Station"].global_coordinates["latitude"] = iss_position["latitude"]
            page.results_dict["International Space Station"].global_coordinates["longitude"] = iss_position["longitude"]

    def update_api_page(self,page=None,next_page=None,url="",dict_key_key=None,object_type=None,list_key="results"):
        """
        Updates the contents of an API Page

        Args:
            page: Api_Page object
            next: Boolean, gets the next page of objects if True. Gets the previous if False
            url: Url to request JSON objects with {} properly placed to input the updated offset
            dict_key_key: The key that will be used as the key for the dict of objects
            object_type: Class of the objects that will be the values of the dict
            list_key: Key to access the list of JSONs of the object type. "results" by default
            is_ordered_dict: Boolean, to use or no an oredered dict for the page
        """
        #Sanity Check
        if type(page) != Api_Page:
            return True

        if type(next_page) == bool:
            page_flip_result = False
            if next_page:
                page_flip_result = page.next_page()
            else:
                page_flip_result = page.previous_page()
            if not page_flip_result:
                return True

        json_results = request_json(url.format(page.current_offset))
        page.results_dict = {e.get(dict_key_key): object_type(e) for e in json_results.get(list_key)}

        count = json_results.get("count")
        if count != None:
            page.count = count
        else:
            page.count = 1
        
        return True

def request_json(url=""):
    """
    Generic function that does an API request for a JSON object
    Args:
        url: request URL
    Returns:
        JSON object if successful
        None otherwise
    """
    try:
        logging.debug("Getting {}".format(url))
        r = requests.get(url)
        return r.json()
    except requests.exceptions.ConnectionError as e:
        logging.error("Unable to Connect to {}".format(url))
        raise e
        


class Api_Page():
    """
    Controls the last accessed "page" of the API
    Buffers the results of the Api requests, Tracks the offset for future requests
    """
    def __init__(self,offset_delta = const.DEFAULT_OFFSET_DELTA):
        self.offset_delta = offset_delta
        self.count = 0 #Count of Items available
        self.current_offset = 0
        self.maximum_offset = 1000

        # Page Number based on the Offset and Maximum number of objects
        self.current_page_number = 1
        self.maximum_page_number = 1
        self.results_dict = {} #Currently buffered Results

    def next_page(self):
        """
        Increments the current offset with offset delta. 
        Returns True if successful, Returns False otherwise
        """
        modded_offset = self.current_offset + self.offset_delta
        if modded_offset <= self.maximum_offset:
            self.current_page_number+=1
            self.current_offset = modded_offset
            return True
        return False

    def previous_page(self):
        """
        Decrements the current offset with offset delta. 
        Returns True if successful, Returns False otherwise
        """
        modded_offset = self.current_offset - self.offset_delta
        if modded_offset >= 0 :
            self.current_offset = modded_offset
            self.current_page_number-=1
            return True
        return False
    
    @property
    def count(self):
        return self.count
    @count.setter
    def count(self,new_count):
        self.maximum_offset = new_count - self.offset_delta
        self._count = new_count
        self.maximum_page_number = int(self.maximum_offset/self.offset_delta)+1



from src.app import WordenApp
import src.const as const
import argparse
import logging

def main():
    App = WordenApp()
    App.run()
    

if __name__ == "__main__":
    
    parser = argparse.ArgumentParser(prog="worden",
            description='TUI Space operations center',
            formatter_class=argparse.RawDescriptionHelpFormatter,
            epilog=const.MSG_CONTROLS_HELP )
    
    parser.add_argument('--debug', '-d', action='store_true', help="Debug messages will be written in worden.log")
    parser.add_argument('--version', '-v',action='store_true', help='Print version and exit')
    parser.add_argument('--refresh','-r', metavar='S', type=int,
        help='Time in 10ths of second to refresh API data; {} by default'.format(const.KEYPRESS_TIMEOUT))

    args = parser.parse_args()
    if args.version:
        print("worden version: {}".format(const.VERSION))
        exit(0)
    if args.debug:
        logging.basicConfig(filename="worden.log", level=logging.DEBUG)
    if args.refresh:
        const.KEYPRESS_TIMEOUT = args.refresh
    main()



import datetime as dt

def parse_str_to_date(date_str):
    """
    Recieves a Date String (e.g. 2019-10-09)
    and returns a datetime object
    """
    #T22:25:00-03:00
    if type(date_str) != str:
        return None

    return dt.datetime(
        int(date_str[0:4]), #Year
        int(date_str[5:7]), #Month
        int(date_str[8:10]), #Day
    )


from src.api.trackable_object import TrackableObject
from src.api.api_utils import parse_str_to_date
import datetime

class Body(TrackableObject):

    def __init__(self,body_json):
        self.name =  body_json.get("englishName")
        self.is_planet =  body_json.get("isPlanet")
        self.semimajorAxis = body_json.get("semimajorAxis")
        self.perihelion = body_json.get("perihelion")
        self.aphelion = body_json.get("aphelion")
        self.eccentricity = body_json.get("eccentricity")
        self.inclination = body_json.get("inclination")

        json_mass = body_json.get("mass")
        self.mass = ""
        if json_mass != None:
            self.mass = float("{}E{}".format(json_mass.get("massValue"),json_mass.get("massExponent")))

        json_vol = body_json.get("vol")
        self.vol = ""
        if json_vol != None:
            self.vol = float ("{}E{}".format(json_vol.get("volValue"),json_vol.get("volExponent")))
        self.density = body_json.get("density")
        self.gravity = body_json.get("gravity")
        self.escape = body_json.get("escape")
        self.mean_radius = body_json.get("meanRadius")
        self.equa_radius = body_json.get("equaRadius")
        self.polar_radius = body_json.get("polarRadius")
        self.flattening = body_json.get("flattening")
        self.sideral_orbit = body_json.get("sideralOrbit")
        self.sideral_rotation = body_json.get("sideralRotation")
        self.discovered_by = body_json.get("discoveredBy")
        self.discovery_date = body_json.get("discoveryDate")
        self.alternative_name = body_json.get("alternativeName")

    def __repr__(self):
        s = "{}".format(self.name)

        if self.alternative_name != "":
            s+= "\nALTERNATE NAME: {}".format(self.alternative_name)
        if self.is_planet:
            s += "\nPLANET\n"
        if self.discovered_by != "":
            s +="\nDISCOVERED BY: {} on {}".format(self.discovered_by,self.discovery_date)
        
        s += """\nAPHELION:{} km\t|\tPERIHELION:{} km
        \nSEMI-MAJOR AXIS: {} m
        \nECC: {}|\tINC: {}°
        \nMASS: {} kg|\tVOLUME: {}|\tDENSITY: {} kg/m^3
        \nGRAVITY: {} m/s^2|\tESCAPE VELOCITY: {} km/s
        \nMEAN RADIUS: {} km |\tFLATTENING: {}
        \n\tEQUATOR RADIUS: {} km|\tPOLAR RADIUS: {} km
        \nSIDERAL ORBIT: {} days|\tSIDERAL ROTATION: {} hours
        """.format(
            self.perihelion,
            self.aphelion,
            self.semimajorAxis,
            self.eccentricity,
            self.inclination,
            self.mass,
            self.vol,
            self.density,
            self.gravity,
            self.escape,
            self.mean_radius,
            self.flattening,
            self.equa_radius,
            self.polar_radius,
            self.sideral_orbit,
            self.sideral_rotation
            )
            
        return s



from src.ui.ui_utils import TextBox, WordenForm
from src.api.api_man import Api_Page
import src.const as const
import npyscreen
import logging
import time
import requests

class ListAndDetailsForm(WordenForm):
    """
    A generic Form with a list of selectable objects on the left and a 
    detail panel on the right.
    """
    def create(self, *args, **keywords):
        super(ListAndDetailsForm, self).create(*args, **keywords)
        
        #To order or not the keys 
        self.order_keys = False
        #To periodically update the Loaded API Data
        self.refresh_api_data=True

        self.w_object_selection = self.add(npyscreen.BoxTitle, name="",
            values=[],
            max_width=40,
            rely=self.PADDING_Y,
            relx=self.PADDING_X,
        )
        self.w_object_selection.when_value_edited = self.update_object_details
        self.selected_object = None

        self.w_object_details_box = self.add(TextBox,
            name="DETAILS",
            max_width= self.USEABLE_X-self.w_object_selection.max_width-5, 
            max_height = self.USEABLE_Y-3,
            #Relx of the previous + width of the previous - Padding 
            relx = self.w_object_selection.relx + self.w_object_selection.width - 2*self.PADDING_X, 
            rely=self.PADDING_Y,
            autowrap=True,
            footer="{}: Track".format(const.CONTROLS["track"])
            )       

    def set_order_keys(self,order_keys):
        self.order_keys = order_keys

    def set_refresh_api_data(self,refresh):
        self.refresh_api_data = refresh

    def set_api_type(self,api_type):
        """
        Sets the API type and populates the current API Page
        """
        if type(api_type) != const.API_TYPES:
            raise TypeError("{} not in API_TYPES".format(api_type))
        self.api_type = api_type
            
        try:
            npyscreen.notify("Fetching {}\nPlease Wait...".format(api_type.value),title="INTIALIZING",wide=True)
            self.parentApp.api_man.getters_dict.get(self.api_type)()
            self.api_page = self.parentApp.api_man.pages.get(self.api_type)
        except requests.exceptions.ConnectionError:
            npyscreen.notify_wait(const.MSG_CONNECTION_ERROR,title="Connection Error",form_color='WARNING')
            self.api_page = Api_Page()
            

    def update_object_details(self):
        if type(self.w_object_selection.value) != int: #Sanity Check
            return
        
        #Get details of the current selected object
        self.selected_object = self.api_page.results_dict.get(
            self.w_object_selection.values[self.w_object_selection.value])

        logging.debug("Selected Object {}".format(self.w_object_selection.values[self.w_object_selection.value]))
        self.w_object_details_box.value = str(self.selected_object)
        self.w_object_details_box.entry_widget.reformat_preserve_nl()
        self.w_object_details_box.display()        
        
    def track_object(self,*args,**keywords):
        if self.selected_object == None  : #Sanity Check
            return
        self.parentApp.set_tracked_object(
            trackable_object=self.selected_object,
            trackable_object_key=self.w_object_selection.values[self.w_object_selection.value],
            trackable_object_type=self.api_type)
        npyscreen.notify("Now Tracking {}".format(self.selected_object.name),title="Object Selected")
        time.sleep(1)

    def h_increment_offset(self, *args, **keywords):
        """
        Method used by forms that manipulate API data, to fetch the next values
        """
        self.parentApp.api_man.getters_dict.get(self.api_type)(next_page=True)
        self.update_form()


    def h_decrement_offset(self, *args, **keywords):
        """
        Method used by forms that manipulate API data, to fetch the previous values
        """
        self.parentApp.api_man.getters_dict.get(self.api_type)(next_page=False)
        self.update_form()

    def update_form(self):
        self.w_object_selection.values = list(self.api_page.results_dict.keys())
        if self.order_keys:
            self.w_object_selection.values.sort()
        self.w_object_selection.footer = "< {}/{} >".format(self.api_page.current_page_number,self.api_page.maximum_page_number)
        self.w_object_selection.update()
        self.update_object_details()

    def while_waiting(self):
        if self.refresh_api_data == False:
            return
        try:
            self.parentApp.api_man.getters_dict[self.api_type]()
        except requests.exceptions.ConnectionError:
            npyscreen.notify_wait(const.MSG_CONNECTION_ERROR,title="Connection Error",form_color='WARNING')
        self.update_form()



import npyscreen, curses
import drawille
import copy
from src.ui.ui_utils import TextBox, WordenForm, draw_image_on_canvas
from PIL import Image
from collections import namedtuple
import logging

Area=namedtuple("Area",["min_x","min_y","max_x","max_y"])
MAP_IMAGE_FILEPATH = "src/ui/resources/mapimg.png"
MAP_IMAGE_THRESHOLD = 225

class MapForm(WordenForm):
    def create(self, *args, **keywords):
        super(MapForm, self).create(*args, **keywords)

        self.w_map_selection = self.add(npyscreen.BoxTitle, name="",
            values=["WORLD"],
            #values=["WORLD", "ORBIT", "SYSTEM"],
            max_width=20,
            rely=self.PADDING_Y,
            relx=self.PADDING_X,
            #check_value_change=True
        )
        self.w_map_selection.value = 0
        
        self.w_map_box = self.add(TextBox,
            name="MAP",
            #max_width= self.USEABLE_X-self.w_map_selection.max_width - 2*self.PADDING_X, 
            max_width= self.USEABLE_X-self.w_map_selection.max_width-5, 
            max_height = self.USEABLE_Y-3,
            #Relx of the previous + width of the previous - Padding 
            relx = self.w_map_selection.relx + self.w_map_selection.width - 2*self.PADDING_X, 
            rely=self.PADDING_Y
            )       
        self.w_map_box.editable=False


        ##Pixel X,Y Coordinates that limit the size of the Map
        ## It is updated after setting
        self.map_pixel_limits = {
            "min_x":0,
            "min_y":0,
            "max_x":self.w_map_box.max_width*2,
            "max_y":(self.w_map_box.max_height - self.w_map_box.rely)*4
        }
        
        ##Canvas with Only the map. Each refresh just re-print
        ## this canvas instead of redrawing the entire map
        self.base_map_canvas = drawille.Canvas()
        draw_image_on_canvas(open(MAP_IMAGE_FILEPATH,'rb'),
            MAP_IMAGE_THRESHOLD,
            False,
            self.base_map_canvas,
            self.map_pixel_limits)
        #Canvas where the objects will be tracked on
        self.map_canvas = drawille.Canvas()

    def update_form(self):
        """
        Clears the screen, redraws the map and 
        draw the tracked object if there is one
        Sets the value of the map_box as the return of the Canvas.frame() function
        """
        self.w_map_box.update(clear=True)
        self.map_canvas = copy.deepcopy(self.base_map_canvas)

        #WORLD MAP
        if (self.w_map_selection.get_value()==self.w_map_selection.values.index("WORLD")):
            self.draw_tracked_object()
            ##TODO Redraw all other trackable objects

        self.w_map_box.value=self.map_canvas.frame(
            self.map_pixel_limits["min_x"],
            self.map_pixel_limits["min_y"],
            self.map_pixel_limits["max_x"],
            self.map_pixel_limits["max_y"])


    def draw_tracked_object(self):
        """
        Converts latitude/longitude positions into Canvas positions
        Draws the current tracked object
        """
        footer_msg="TRACKING:"
        if self.parentApp.tracked_object is None:
            footer_msg+=" -"
            self.w_map_box.footer=footer_msg
            return
        
        coords = self.parentApp.tracked_object.track_global_coordinates()
        if coords == None:
            footer_msg+="\"{}\" COORDS:(N/A)".format(str(self.parentApp.tracked_object.name))

        else:
            lat,lon = coords
            coord_msg="{},{}".format(round(lat,2),round(lon,2))
            footer_msg+="\"{}\" COORDS:({})".format(str(self.parentApp.tracked_object.name),coord_msg)
            point = convert_gps_coord_to_canvas_coord(
                lat,lon,
                self.map_pixel_limits)
            self.map_canvas.set(point[0],point[1])
            #self.map_canvas.set_text(point[0],point[1],coord_msg)
            h_line = drawille.line(self.map_pixel_limits["min_x"],point[1],self.map_pixel_limits["max_x"],point[1])
            v_line = drawille.line(point[0],self.map_pixel_limits["min_y"],point[0],self.map_pixel_limits["max_y"])
            for i in v_line:
                self.map_canvas.set(i[0],i[1])
            for i in h_line:
                self.map_canvas.set(i[0],i[1])

        self.w_map_box.footer=footer_msg   


def convert_gps_coord_to_canvas_coord(latitude,longitude,map_pixel_limits):
    """
    Converts Latitude/Longitude to coordinates

    args:
        latitude: number between -90 and 90
        longitude: number between -180 and 180 
        map_pixel_limits: 
    returns:
    """
    if int(latitude) not in range(-90,90):
        raise IndexError
    if int(longitude) not in range(-180,180):
        raise IndexError

    #The canvas Y Axis is positive downwards, therefore we negate the latitude for %
    latitude_in_perc = abs((-latitude + 90)/180)
    longitude_in_perc = abs((longitude + 180)/360)

    x_range = map_pixel_limits["max_x"] - map_pixel_limits["min_x"]
    y_range = map_pixel_limits["min_y"] - map_pixel_limits["max_y"]
    
    x_coord = int(abs( map_pixel_limits["min_x"] + longitude_in_perc * x_range))
    y_coord = int(abs( map_pixel_limits["min_y"] + latitude_in_perc * y_range))

    #logging.debug("GPS longitude {},latitude {} to Pixel {},{}".format(longitude,latitude,x_coord,y_coord))
    return (x_coord,y_coord)



"""
Drawile "PIXEL"
dots:
,___,
|1 4|
|2 5|
|3 6|
|7 8|
`````
"""


from .trackable_object import TrackableObject
import datetime as dt

def parse_net_launch_window(nw_str):
    #2019-10-09T22:25:00-03:00
    if type(nw_str) != str:
        return None

    return dt.datetime(
        int(nw_str[0:4]), #Year
        int(nw_str[5:7]), #Month
        int(nw_str[8:10]), #Day
        int(nw_str[11:13]), #Hour
        int(nw_str[14:16]), #Minute
        int(nw_str[17:19]) #Second
    )


class Launch(TrackableObject):
    def __init__(self, launch_json):
        self.name = launch_json["name"] or ""
        self.net_window = parse_net_launch_window(launch_json["net"])
        self.status = launch_json["status"]["name"] or ""
        
        """
        mission	
            id	25
            launch_library_id	1155
            name	"Cygnus CRS NG-12"
            description	"This is the 13th planned flight of the Orbital ATK's uncrewed resupply spacecraft Cygnus and its 12th flight to the International Space Station under the Commercial Resupply Services contract with NASA."
            type	"Resupply"
            orbit	"Low Earth Orbit"
            orbit_abbrev	"LEO"
        """
        self.mission = launch_json["mission"] or {"name":"N/A","type":"N/A","description":"N/A","orbit":"N/A"}

        self.pad = launch_json["pad"] or {}

    def __repr__(self):
        return """
        \nNAME: {}
        \nSTATUS: {}\tDATE: {} 
        \nMISSION: {}
        \tTYPE: {}
        \tORBIT: {}
        \nPAD: {}
        \tLOCATION: {}
        \nMISSION DETAILS: {}
        """.format(
            self.name,
            self.status, self.net_window,
            self.mission.get('name'),
            self.mission.get('type'),
            self.mission.get('orbit'),
            self.pad.get("name"),
            self.pad.get("location").get("name"),
            self.mission.get('description')
            )

    def __str__(self):
        return self.__repr__()

    def track_global_coordinates(self):
        return float(self.pad["latitude"]),float(self.pad["longitude"])



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="worden",
    version="1.0.1",
    author="João Guimarães",
    author_email="jvlsg-github@ipriva.org",
    description="TUI Space operations center",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/jvlsg/Worden",
    #packages=setuptools.find_packages(where="worden_pkg", include=["src.*",]),
    packages=["worden_pkg","worden_pkg.src.api","worden_pkg.src.ui"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Environment :: Console :: Curses",
        "Intended Audience :: Education",
        "Natural Language :: English"
    ],
    python_requires='>=3.7',
)


from src.api.trackable_object import TrackableObject
from src.api.api_utils import parse_str_to_date
import datetime

class Event(TrackableObject):
    
    def __init__(self,event_json):
        self.name = event_json.get("name")
        self.type = event_json.get("type").get("name")
        self.description = event_json.get("description")
        self.date = event_json.get("date")
        self.location = event_json.get("location")

        self.news_url = event_json.get("news_url")
        if self.news_url == None:
            self.news_url = ""

        self.launches=[]
        for l in event_json.get("launches"):
            self.launches.append(l.get("name"))

        self.spacestations = []
        for s in event_json.get("spacestations"):
            self.spacestations.append(s.get("name"))

    def __repr__(self):
        return """NAME: {}\t TYPE: {}
        \nDATE: {}\tLOCATION: {}
        \n{}
        \nLAUNCHES: {}
        \nSPACE STATIONS: {}
        \nNEWS URL:{}
        """.format(self.name,self.type,self.date,self.location,self.description,"\n\t".join(self.launches),"\n\t".join(self.spacestations),self.news_url)